Documentation
¶
Index ¶
- Constants
- Variables
- func RegisterAreaInsightsServer(s grpc.ServiceRegistrar, srv AreaInsightsServer)
- type AreaInsightsClient
- type AreaInsightsServer
- type ComputeInsightsRequest
- func (*ComputeInsightsRequest) Descriptor() ([]byte, []int)deprecated
- func (x *ComputeInsightsRequest) GetFilter() *Filter
- func (x *ComputeInsightsRequest) GetInsights() []Insight
- func (*ComputeInsightsRequest) ProtoMessage()
- func (x *ComputeInsightsRequest) ProtoReflect() protoreflect.Message
- func (x *ComputeInsightsRequest) Reset()
- func (x *ComputeInsightsRequest) String() string
- type ComputeInsightsResponse
- func (*ComputeInsightsResponse) Descriptor() ([]byte, []int)deprecated
- func (x *ComputeInsightsResponse) GetCount() int64
- func (x *ComputeInsightsResponse) GetPlaceInsights() []*PlaceInsight
- func (*ComputeInsightsResponse) ProtoMessage()
- func (x *ComputeInsightsResponse) ProtoReflect() protoreflect.Message
- func (x *ComputeInsightsResponse) Reset()
- func (x *ComputeInsightsResponse) String() string
- type Filter
- func (*Filter) Descriptor() ([]byte, []int)deprecated
- func (x *Filter) GetLocationFilter() *LocationFilter
- func (x *Filter) GetOperatingStatus() []OperatingStatus
- func (x *Filter) GetPriceLevels() []PriceLevel
- func (x *Filter) GetRatingFilter() *RatingFilter
- func (x *Filter) GetTypeFilter() *TypeFilter
- func (*Filter) ProtoMessage()
- func (x *Filter) ProtoReflect() protoreflect.Message
- func (x *Filter) Reset()
- func (x *Filter) String() string
- type Insight
- type LocationFilter
- func (*LocationFilter) Descriptor() ([]byte, []int)deprecated
- func (m *LocationFilter) GetArea() isLocationFilter_Area
- func (x *LocationFilter) GetCircle() *LocationFilter_Circle
- func (x *LocationFilter) GetCustomArea() *LocationFilter_CustomArea
- func (x *LocationFilter) GetRegion() *LocationFilter_Region
- func (*LocationFilter) ProtoMessage()
- func (x *LocationFilter) ProtoReflect() protoreflect.Message
- func (x *LocationFilter) Reset()
- func (x *LocationFilter) String() string
- type LocationFilter_Circle
- func (*LocationFilter_Circle) Descriptor() ([]byte, []int)deprecated
- func (m *LocationFilter_Circle) GetCenter() isLocationFilter_Circle_Center
- func (x *LocationFilter_Circle) GetLatLng() *latlng.LatLng
- func (x *LocationFilter_Circle) GetPlace() string
- func (x *LocationFilter_Circle) GetRadius() int32
- func (*LocationFilter_Circle) ProtoMessage()
- func (x *LocationFilter_Circle) ProtoReflect() protoreflect.Message
- func (x *LocationFilter_Circle) Reset()
- func (x *LocationFilter_Circle) String() string
- type LocationFilter_Circle_
- type LocationFilter_Circle_LatLng
- type LocationFilter_Circle_Place
- type LocationFilter_CustomArea
- func (*LocationFilter_CustomArea) Descriptor() ([]byte, []int)deprecated
- func (x *LocationFilter_CustomArea) GetPolygon() *LocationFilter_CustomArea_Polygon
- func (*LocationFilter_CustomArea) ProtoMessage()
- func (x *LocationFilter_CustomArea) ProtoReflect() protoreflect.Message
- func (x *LocationFilter_CustomArea) Reset()
- func (x *LocationFilter_CustomArea) String() string
- type LocationFilter_CustomArea_
- type LocationFilter_CustomArea_Polygon
- func (*LocationFilter_CustomArea_Polygon) Descriptor() ([]byte, []int)deprecated
- func (x *LocationFilter_CustomArea_Polygon) GetCoordinates() []*latlng.LatLng
- func (*LocationFilter_CustomArea_Polygon) ProtoMessage()
- func (x *LocationFilter_CustomArea_Polygon) ProtoReflect() protoreflect.Message
- func (x *LocationFilter_CustomArea_Polygon) Reset()
- func (x *LocationFilter_CustomArea_Polygon) String() string
- type LocationFilter_Region
- func (*LocationFilter_Region) Descriptor() ([]byte, []int)deprecated
- func (x *LocationFilter_Region) GetPlace() string
- func (m *LocationFilter_Region) GetRegion() isLocationFilter_Region_Region
- func (*LocationFilter_Region) ProtoMessage()
- func (x *LocationFilter_Region) ProtoReflect() protoreflect.Message
- func (x *LocationFilter_Region) Reset()
- func (x *LocationFilter_Region) String() string
- type LocationFilter_Region_
- type LocationFilter_Region_Place
- type OperatingStatus
- func (OperatingStatus) Descriptor() protoreflect.EnumDescriptor
- func (x OperatingStatus) Enum() *OperatingStatus
- func (OperatingStatus) EnumDescriptor() ([]byte, []int)deprecated
- func (x OperatingStatus) Number() protoreflect.EnumNumber
- func (x OperatingStatus) String() string
- func (OperatingStatus) Type() protoreflect.EnumType
- type PlaceInsight
- type PriceLevel
- type RatingFilter
- func (*RatingFilter) Descriptor() ([]byte, []int)deprecated
- func (x *RatingFilter) GetMaxRating() float32
- func (x *RatingFilter) GetMinRating() float32
- func (*RatingFilter) ProtoMessage()
- func (x *RatingFilter) ProtoReflect() protoreflect.Message
- func (x *RatingFilter) Reset()
- func (x *RatingFilter) String() string
- type TypeFilter
- func (*TypeFilter) Descriptor() ([]byte, []int)deprecated
- func (x *TypeFilter) GetExcludedPrimaryTypes() []string
- func (x *TypeFilter) GetExcludedTypes() []string
- func (x *TypeFilter) GetIncludedPrimaryTypes() []string
- func (x *TypeFilter) GetIncludedTypes() []string
- func (*TypeFilter) ProtoMessage()
- func (x *TypeFilter) ProtoReflect() protoreflect.Message
- func (x *TypeFilter) Reset()
- func (x *TypeFilter) String() string
- type UnimplementedAreaInsightsServer
- type UnsafeAreaInsightsServer
Constants ¶
const (
AreaInsights_ComputeInsights_FullMethodName = "/google.maps.areainsights.v1.AreaInsights/ComputeInsights"
)
Variables ¶
var ( Insight_name = map[int32]string{ 0: "INSIGHT_UNSPECIFIED", 1: "INSIGHT_COUNT", 2: "INSIGHT_PLACES", } Insight_value = map[string]int32{ "INSIGHT_UNSPECIFIED": 0, "INSIGHT_COUNT": 1, "INSIGHT_PLACES": 2, } )
Enum value maps for Insight.
var ( OperatingStatus_name = map[int32]string{ 0: "OPERATING_STATUS_UNSPECIFIED", 1: "OPERATING_STATUS_OPERATIONAL", 3: "OPERATING_STATUS_PERMANENTLY_CLOSED", 4: "OPERATING_STATUS_TEMPORARILY_CLOSED", } OperatingStatus_value = map[string]int32{ "OPERATING_STATUS_UNSPECIFIED": 0, "OPERATING_STATUS_OPERATIONAL": 1, "OPERATING_STATUS_PERMANENTLY_CLOSED": 3, "OPERATING_STATUS_TEMPORARILY_CLOSED": 4, } )
Enum value maps for OperatingStatus.
var ( PriceLevel_name = map[int32]string{ 0: "PRICE_LEVEL_UNSPECIFIED", 1: "PRICE_LEVEL_FREE", 2: "PRICE_LEVEL_INEXPENSIVE", 3: "PRICE_LEVEL_MODERATE", 4: "PRICE_LEVEL_EXPENSIVE", 5: "PRICE_LEVEL_VERY_EXPENSIVE", } PriceLevel_value = map[string]int32{ "PRICE_LEVEL_UNSPECIFIED": 0, "PRICE_LEVEL_FREE": 1, "PRICE_LEVEL_INEXPENSIVE": 2, "PRICE_LEVEL_MODERATE": 3, "PRICE_LEVEL_EXPENSIVE": 4, "PRICE_LEVEL_VERY_EXPENSIVE": 5, } )
Enum value maps for PriceLevel.
var AreaInsights_ServiceDesc = grpc.ServiceDesc{ ServiceName: "google.maps.areainsights.v1.AreaInsights", HandlerType: (*AreaInsightsServer)(nil), Methods: []grpc.MethodDesc{ { MethodName: "ComputeInsights", Handler: _AreaInsights_ComputeInsights_Handler, }, }, Streams: []grpc.StreamDesc{}, Metadata: "google/maps/areainsights/v1/area_insights_service.proto", }
AreaInsights_ServiceDesc is the grpc.ServiceDesc for AreaInsights service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)
var File_google_maps_areainsights_v1_area_insights_service_proto protoreflect.FileDescriptor
Functions ¶
func RegisterAreaInsightsServer ¶
func RegisterAreaInsightsServer(s grpc.ServiceRegistrar, srv AreaInsightsServer)
Types ¶
type AreaInsightsClient ¶
type AreaInsightsClient interface {
// This method lets you retrieve insights about areas using a variety of
// filter such as: area, place type, operating status, price level
// and ratings. Currently "count" and "places" insights are supported. With
// "count" insights you can answer questions such as "How many restaurant are
// located in California that are operational, are inexpensive and have an
// average rating of at least 4 stars" (see `insight` enum for more details).
// With "places" insights, you can determine which places match the
// requested filter. Clients can then use those place resource names to fetch
// more details about each individual place using the Places API.
ComputeInsights(ctx context.Context, in *ComputeInsightsRequest, opts ...grpc.CallOption) (*ComputeInsightsResponse, error)
}
AreaInsightsClient is the client API for AreaInsights service.
For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.
func NewAreaInsightsClient ¶
func NewAreaInsightsClient(cc grpc.ClientConnInterface) AreaInsightsClient
type AreaInsightsServer ¶
type AreaInsightsServer interface {
// This method lets you retrieve insights about areas using a variety of
// filter such as: area, place type, operating status, price level
// and ratings. Currently "count" and "places" insights are supported. With
// "count" insights you can answer questions such as "How many restaurant are
// located in California that are operational, are inexpensive and have an
// average rating of at least 4 stars" (see `insight` enum for more details).
// With "places" insights, you can determine which places match the
// requested filter. Clients can then use those place resource names to fetch
// more details about each individual place using the Places API.
ComputeInsights(context.Context, *ComputeInsightsRequest) (*ComputeInsightsResponse, error)
}
AreaInsightsServer is the server API for AreaInsights service. All implementations should embed UnimplementedAreaInsightsServer for forward compatibility
type ComputeInsightsRequest ¶
type ComputeInsightsRequest struct {
// Required. Insights to compute. Currently only INSIGHT_COUNT and
// INSIGHT_PLACES are supported.
Insights []Insight `protobuf:"varint,4,rep,packed,name=insights,proto3,enum=google.maps.areainsights.v1.Insight" json:"insights,omitempty"`
// Required. Insight filter.
Filter *Filter `protobuf:"bytes,5,opt,name=filter,proto3" json:"filter,omitempty"`
// contains filtered or unexported fields
}
Request for the ComputeInsights RPC.
func (*ComputeInsightsRequest) Descriptor
deprecated
func (*ComputeInsightsRequest) Descriptor() ([]byte, []int)
Deprecated: Use ComputeInsightsRequest.ProtoReflect.Descriptor instead.
func (*ComputeInsightsRequest) GetFilter ¶
func (x *ComputeInsightsRequest) GetFilter() *Filter
func (*ComputeInsightsRequest) GetInsights ¶
func (x *ComputeInsightsRequest) GetInsights() []Insight
func (*ComputeInsightsRequest) ProtoMessage ¶
func (*ComputeInsightsRequest) ProtoMessage()
func (*ComputeInsightsRequest) ProtoReflect ¶
func (x *ComputeInsightsRequest) ProtoReflect() protoreflect.Message
func (*ComputeInsightsRequest) Reset ¶
func (x *ComputeInsightsRequest) Reset()
func (*ComputeInsightsRequest) String ¶
func (x *ComputeInsightsRequest) String() string
type ComputeInsightsResponse ¶
type ComputeInsightsResponse struct {
// Result for Insights.INSIGHT_COUNT.
Count *int64 `protobuf:"varint,1,opt,name=count,proto3,oneof" json:"count,omitempty"`
// Result for Insights.INSIGHT_PLACES.
PlaceInsights []*PlaceInsight `protobuf:"bytes,5,rep,name=place_insights,json=placeInsights,proto3" json:"place_insights,omitempty"`
// contains filtered or unexported fields
}
Response for the ComputeInsights RPC.
func (*ComputeInsightsResponse) Descriptor
deprecated
func (*ComputeInsightsResponse) Descriptor() ([]byte, []int)
Deprecated: Use ComputeInsightsResponse.ProtoReflect.Descriptor instead.
func (*ComputeInsightsResponse) GetCount ¶
func (x *ComputeInsightsResponse) GetCount() int64
func (*ComputeInsightsResponse) GetPlaceInsights ¶
func (x *ComputeInsightsResponse) GetPlaceInsights() []*PlaceInsight
func (*ComputeInsightsResponse) ProtoMessage ¶
func (*ComputeInsightsResponse) ProtoMessage()
func (*ComputeInsightsResponse) ProtoReflect ¶
func (x *ComputeInsightsResponse) ProtoReflect() protoreflect.Message
func (*ComputeInsightsResponse) Reset ¶
func (x *ComputeInsightsResponse) Reset()
func (*ComputeInsightsResponse) String ¶
func (x *ComputeInsightsResponse) String() string
type Filter ¶
type Filter struct {
// Required. Restricts results to places which are located in the area
// specified by location filters.
LocationFilter *LocationFilter `protobuf:"bytes,1,opt,name=location_filter,json=locationFilter,proto3" json:"location_filter,omitempty"`
// Required. Place type filters.
TypeFilter *TypeFilter `protobuf:"bytes,2,opt,name=type_filter,json=typeFilter,proto3" json:"type_filter,omitempty"`
// Optional. Restricts results to places whose operating status is included on
// this list. If operating_status is not set, OPERATING_STATUS_OPERATIONAL is
// used as default.
OperatingStatus []OperatingStatus `` /* 163-byte string literal not displayed */
// Optional. Restricts results to places whose price level is included on this
// list. If `price_levels` is not set, all price levels are included in the
// results.
PriceLevels []PriceLevel `` /* 146-byte string literal not displayed */
// Optional. Restricts results to places whose average user ratings are in the
// range specified by rating_filter. If rating_filter is not set, all ratings
// are included in the result.
RatingFilter *RatingFilter `protobuf:"bytes,5,opt,name=rating_filter,json=ratingFilter,proto3" json:"rating_filter,omitempty"`
// contains filtered or unexported fields
}
Filters for the ComputeInsights RPC.
func (*Filter) Descriptor
deprecated
func (*Filter) GetLocationFilter ¶
func (x *Filter) GetLocationFilter() *LocationFilter
func (*Filter) GetOperatingStatus ¶
func (x *Filter) GetOperatingStatus() []OperatingStatus
func (*Filter) GetPriceLevels ¶
func (x *Filter) GetPriceLevels() []PriceLevel
func (*Filter) GetRatingFilter ¶
func (x *Filter) GetRatingFilter() *RatingFilter
func (*Filter) GetTypeFilter ¶
func (x *Filter) GetTypeFilter() *TypeFilter
func (*Filter) ProtoMessage ¶
func (*Filter) ProtoMessage()
func (*Filter) ProtoReflect ¶
func (x *Filter) ProtoReflect() protoreflect.Message
type Insight ¶
type Insight int32
Supported insights.
const ( // Not Specified. Insight_INSIGHT_UNSPECIFIED Insight = 0 // Count insight. // // When this insight is specified ComputeInsights returns the number of // places that match the specified filter criteria. // // Example request: // “` // // { // "insights": ["INSIGHT_COUNT"], // "filter": { // "locationFilter": { // "region": { // "place": "places/ChIJPV4oX_65j4ARVW8IJ6IJUYs" // } // }, // "typeFilter": { // "includedTypes": ["restaurant"] // }, // "operatingStatus": ["OPERATING_STATUS_OPERATIONAL"], // "priceLevels": [ // "PRICE_LEVEL_FREE", // "PRICE_LEVEL_INEXPENSIVE" // ], // "ratingFilter": { // "minRating": 4.0 // } // } // } // // “` // // Example response: // “` // // { // "count": 1234 // } // // “` Insight_INSIGHT_COUNT Insight = 1 // Return Places // // When this insight is specified ComputeInsights returns places IDs // that match the specified filter criteria. // // Example request: // “` // // { // "insights": ["INSIGHT_PLACES"], // "filter": { // "locationFilter": { // "region": { // "place": "places/ChIJPV4oX_65j4ARVW8IJ6IJUYs" // } // }, // "typeFilter": { // "includedTypes": ["restaurant"] // }, // "operatingStatus": ["OPERATING_STATUS_OPERATIONAL"], // "priceLevels": [ // "PRICE_LEVEL_FREE", // "PRICE_LEVEL_INEXPENSIVE" // ], // "ratingFilter": { // "minRating": 4.0 // } // } // } // // “` // // Example response: // “` // // { // "placeInsights": [ // {"place": "places/ABC"}, // {"place": "places/PQR"}, // {"place": "places/XYZ"} // ] // } // // “` Insight_INSIGHT_PLACES Insight = 2 )
func (Insight) Descriptor ¶
func (Insight) Descriptor() protoreflect.EnumDescriptor
func (Insight) EnumDescriptor
deprecated
func (Insight) Number ¶
func (x Insight) Number() protoreflect.EnumNumber
func (Insight) Type ¶
func (Insight) Type() protoreflect.EnumType
type LocationFilter ¶
type LocationFilter struct {
// One of the following must be specified.
//
// Types that are assignable to Area:
//
// *LocationFilter_Circle_
// *LocationFilter_Region_
// *LocationFilter_CustomArea_
Area isLocationFilter_Area `protobuf_oneof:"area"`
// contains filtered or unexported fields
}
Location filters.
Specifies the area of interest for the insight.
func (*LocationFilter) Descriptor
deprecated
func (*LocationFilter) Descriptor() ([]byte, []int)
Deprecated: Use LocationFilter.ProtoReflect.Descriptor instead.
func (*LocationFilter) GetArea ¶
func (m *LocationFilter) GetArea() isLocationFilter_Area
func (*LocationFilter) GetCircle ¶
func (x *LocationFilter) GetCircle() *LocationFilter_Circle
func (*LocationFilter) GetCustomArea ¶
func (x *LocationFilter) GetCustomArea() *LocationFilter_CustomArea
func (*LocationFilter) GetRegion ¶
func (x *LocationFilter) GetRegion() *LocationFilter_Region
func (*LocationFilter) ProtoMessage ¶
func (*LocationFilter) ProtoMessage()
func (*LocationFilter) ProtoReflect ¶
func (x *LocationFilter) ProtoReflect() protoreflect.Message
func (*LocationFilter) Reset ¶
func (x *LocationFilter) Reset()
func (*LocationFilter) String ¶
func (x *LocationFilter) String() string
type LocationFilter_Circle ¶
type LocationFilter_Circle struct {
// The center of the circle.
//
// Types that are assignable to Center:
//
// *LocationFilter_Circle_LatLng
// *LocationFilter_Circle_Place
Center isLocationFilter_Circle_Center `protobuf_oneof:"center"`
// Optional. The radius of the circle in meters
Radius int32 `protobuf:"varint,3,opt,name=radius,proto3" json:"radius,omitempty"`
// contains filtered or unexported fields
}
A circle is defined by a center point and radius in meters.
func (*LocationFilter_Circle) Descriptor
deprecated
func (*LocationFilter_Circle) Descriptor() ([]byte, []int)
Deprecated: Use LocationFilter_Circle.ProtoReflect.Descriptor instead.
func (*LocationFilter_Circle) GetCenter ¶
func (m *LocationFilter_Circle) GetCenter() isLocationFilter_Circle_Center
func (*LocationFilter_Circle) GetLatLng ¶
func (x *LocationFilter_Circle) GetLatLng() *latlng.LatLng
func (*LocationFilter_Circle) GetPlace ¶
func (x *LocationFilter_Circle) GetPlace() string
func (*LocationFilter_Circle) GetRadius ¶
func (x *LocationFilter_Circle) GetRadius() int32
func (*LocationFilter_Circle) ProtoMessage ¶
func (*LocationFilter_Circle) ProtoMessage()
func (*LocationFilter_Circle) ProtoReflect ¶
func (x *LocationFilter_Circle) ProtoReflect() protoreflect.Message
func (*LocationFilter_Circle) Reset ¶
func (x *LocationFilter_Circle) Reset()
func (*LocationFilter_Circle) String ¶
func (x *LocationFilter_Circle) String() string
type LocationFilter_Circle_ ¶
type LocationFilter_Circle_ struct {
// Area as a circle.
Circle *LocationFilter_Circle `protobuf:"bytes,1,opt,name=circle,proto3,oneof"`
}
type LocationFilter_Circle_Place ¶
type LocationFilter_Circle_Place struct {
// **Format:** Must be in the format `places/PLACE_ID`, where `PLACE_ID`
// is the unique identifier of a place. For example:
// `places/ChIJgUbEo8cfqokR5lP9_Wh_DaM`.
Place string `protobuf:"bytes,2,opt,name=place,proto3,oneof"`
}
type LocationFilter_CustomArea ¶
type LocationFilter_CustomArea struct {
// Required. The custom area represented as a polygon
Polygon *LocationFilter_CustomArea_Polygon `protobuf:"bytes,1,opt,name=polygon,proto3" json:"polygon,omitempty"`
// contains filtered or unexported fields
}
Custom Area.
func (*LocationFilter_CustomArea) Descriptor
deprecated
func (*LocationFilter_CustomArea) Descriptor() ([]byte, []int)
Deprecated: Use LocationFilter_CustomArea.ProtoReflect.Descriptor instead.
func (*LocationFilter_CustomArea) GetPolygon ¶
func (x *LocationFilter_CustomArea) GetPolygon() *LocationFilter_CustomArea_Polygon
func (*LocationFilter_CustomArea) ProtoMessage ¶
func (*LocationFilter_CustomArea) ProtoMessage()
func (*LocationFilter_CustomArea) ProtoReflect ¶
func (x *LocationFilter_CustomArea) ProtoReflect() protoreflect.Message
func (*LocationFilter_CustomArea) Reset ¶
func (x *LocationFilter_CustomArea) Reset()
func (*LocationFilter_CustomArea) String ¶
func (x *LocationFilter_CustomArea) String() string
type LocationFilter_CustomArea_ ¶
type LocationFilter_CustomArea_ struct {
// Custom area specified by a polygon.
CustomArea *LocationFilter_CustomArea `protobuf:"bytes,3,opt,name=custom_area,json=customArea,proto3,oneof"`
}
type LocationFilter_CustomArea_Polygon ¶
type LocationFilter_CustomArea_Polygon struct {
// Optional. The coordinates that define the polygon.
Coordinates []*latlng.LatLng `protobuf:"bytes,1,rep,name=coordinates,proto3" json:"coordinates,omitempty"`
// contains filtered or unexported fields
}
A polygon is represented by a series of connected coordinates in an counterclockwise ordered sequence. The coordinates form a closed loop and define a filled region. The first and last coordinates are equivalent, and they must contain identical values. The format is a simplified version of GeoJSON polygons (we only support one counterclockwise exterior ring).
func (*LocationFilter_CustomArea_Polygon) Descriptor
deprecated
func (*LocationFilter_CustomArea_Polygon) Descriptor() ([]byte, []int)
Deprecated: Use LocationFilter_CustomArea_Polygon.ProtoReflect.Descriptor instead.
func (*LocationFilter_CustomArea_Polygon) GetCoordinates ¶
func (x *LocationFilter_CustomArea_Polygon) GetCoordinates() []*latlng.LatLng
func (*LocationFilter_CustomArea_Polygon) ProtoMessage ¶
func (*LocationFilter_CustomArea_Polygon) ProtoMessage()
func (*LocationFilter_CustomArea_Polygon) ProtoReflect ¶
func (x *LocationFilter_CustomArea_Polygon) ProtoReflect() protoreflect.Message
func (*LocationFilter_CustomArea_Polygon) Reset ¶
func (x *LocationFilter_CustomArea_Polygon) Reset()
func (*LocationFilter_CustomArea_Polygon) String ¶
func (x *LocationFilter_CustomArea_Polygon) String() string
type LocationFilter_Region ¶
type LocationFilter_Region struct {
// Defines a geographic region. Only one type of region (e.g. place) can
// specified at a time.
//
// Types that are assignable to Region:
//
// *LocationFilter_Region_Place
Region isLocationFilter_Region_Region `protobuf_oneof:"region"`
// contains filtered or unexported fields
}
A region is a geographic boundary such as: cities, postal codes, counties, states, etc.
func (*LocationFilter_Region) Descriptor
deprecated
func (*LocationFilter_Region) Descriptor() ([]byte, []int)
Deprecated: Use LocationFilter_Region.ProtoReflect.Descriptor instead.
func (*LocationFilter_Region) GetPlace ¶
func (x *LocationFilter_Region) GetPlace() string
func (*LocationFilter_Region) GetRegion ¶
func (m *LocationFilter_Region) GetRegion() isLocationFilter_Region_Region
func (*LocationFilter_Region) ProtoMessage ¶
func (*LocationFilter_Region) ProtoMessage()
func (*LocationFilter_Region) ProtoReflect ¶
func (x *LocationFilter_Region) ProtoReflect() protoreflect.Message
func (*LocationFilter_Region) Reset ¶
func (x *LocationFilter_Region) Reset()
func (*LocationFilter_Region) String ¶
func (x *LocationFilter_Region) String() string
type LocationFilter_Region_ ¶
type LocationFilter_Region_ struct {
// Area as region.
Region *LocationFilter_Region `protobuf:"bytes,2,opt,name=region,proto3,oneof"`
}
type LocationFilter_Region_Place ¶
type LocationFilter_Region_Place struct {
// The unique identifier of a specific geographic region.
Place string `protobuf:"bytes,1,opt,name=place,proto3,oneof"`
}
type OperatingStatus ¶
type OperatingStatus int32
Operating status of the place.
const ( // Not specified. This value should not be used. OperatingStatus_OPERATING_STATUS_UNSPECIFIED OperatingStatus = 0 // The place is operational and its open during its defined hours. OperatingStatus_OPERATING_STATUS_OPERATIONAL OperatingStatus = 1 // The Place is no longer in business. OperatingStatus_OPERATING_STATUS_PERMANENTLY_CLOSED OperatingStatus = 3 // The place is temporarily closed and expected to reopen in the future. OperatingStatus_OPERATING_STATUS_TEMPORARILY_CLOSED OperatingStatus = 4 )
func (OperatingStatus) Descriptor ¶
func (OperatingStatus) Descriptor() protoreflect.EnumDescriptor
func (OperatingStatus) Enum ¶
func (x OperatingStatus) Enum() *OperatingStatus
func (OperatingStatus) EnumDescriptor
deprecated
func (OperatingStatus) EnumDescriptor() ([]byte, []int)
Deprecated: Use OperatingStatus.Descriptor instead.
func (OperatingStatus) Number ¶
func (x OperatingStatus) Number() protoreflect.EnumNumber
func (OperatingStatus) String ¶
func (x OperatingStatus) String() string
func (OperatingStatus) Type ¶
func (OperatingStatus) Type() protoreflect.EnumType
type PlaceInsight ¶
type PlaceInsight struct {
// The unique identifier of the place. This resource name can be used to
// retrieve details about the place using the [Places
// API](https://developers.google.com/maps/documentation/places/web-service/reference/rest/v1/places/get).
Place string `protobuf:"bytes,1,opt,name=place,proto3" json:"place,omitempty"`
// contains filtered or unexported fields
}
Holds information about a place
func (*PlaceInsight) Descriptor
deprecated
func (*PlaceInsight) Descriptor() ([]byte, []int)
Deprecated: Use PlaceInsight.ProtoReflect.Descriptor instead.
func (*PlaceInsight) GetPlace ¶
func (x *PlaceInsight) GetPlace() string
func (*PlaceInsight) ProtoMessage ¶
func (*PlaceInsight) ProtoMessage()
func (*PlaceInsight) ProtoReflect ¶
func (x *PlaceInsight) ProtoReflect() protoreflect.Message
func (*PlaceInsight) Reset ¶
func (x *PlaceInsight) Reset()
func (*PlaceInsight) String ¶
func (x *PlaceInsight) String() string
type PriceLevel ¶
type PriceLevel int32
Price level of the place.
const ( // Not specified. This value should not be used. PriceLevel_PRICE_LEVEL_UNSPECIFIED PriceLevel = 0 // Place provides free services. PriceLevel_PRICE_LEVEL_FREE PriceLevel = 1 // Place provides inexpensive services. PriceLevel_PRICE_LEVEL_INEXPENSIVE PriceLevel = 2 // Place provides moderately priced services. PriceLevel_PRICE_LEVEL_MODERATE PriceLevel = 3 // Place provides expensive services. PriceLevel_PRICE_LEVEL_EXPENSIVE PriceLevel = 4 // Place provides very expensive services. PriceLevel_PRICE_LEVEL_VERY_EXPENSIVE PriceLevel = 5 )
func (PriceLevel) Descriptor ¶
func (PriceLevel) Descriptor() protoreflect.EnumDescriptor
func (PriceLevel) Enum ¶
func (x PriceLevel) Enum() *PriceLevel
func (PriceLevel) EnumDescriptor
deprecated
func (PriceLevel) EnumDescriptor() ([]byte, []int)
Deprecated: Use PriceLevel.Descriptor instead.
func (PriceLevel) Number ¶
func (x PriceLevel) Number() protoreflect.EnumNumber
func (PriceLevel) String ¶
func (x PriceLevel) String() string
func (PriceLevel) Type ¶
func (PriceLevel) Type() protoreflect.EnumType
type RatingFilter ¶
type RatingFilter struct {
// Optional. Restricts results to places whose average user rating is greater
// than or equal to min_rating. Values must be between 1.0 and 5.0.
MinRating *float32 `protobuf:"fixed32,5,opt,name=min_rating,json=minRating,proto3,oneof" json:"min_rating,omitempty"`
// Optional. Restricts results to places whose average user rating is strictly
// less than or equal to max_rating. Values must be between 1.0 and 5.0.
MaxRating *float32 `protobuf:"fixed32,6,opt,name=max_rating,json=maxRating,proto3,oneof" json:"max_rating,omitempty"`
// contains filtered or unexported fields
}
Average user rating filters.
func (*RatingFilter) Descriptor
deprecated
func (*RatingFilter) Descriptor() ([]byte, []int)
Deprecated: Use RatingFilter.ProtoReflect.Descriptor instead.
func (*RatingFilter) GetMaxRating ¶
func (x *RatingFilter) GetMaxRating() float32
func (*RatingFilter) GetMinRating ¶
func (x *RatingFilter) GetMinRating() float32
func (*RatingFilter) ProtoMessage ¶
func (*RatingFilter) ProtoMessage()
func (*RatingFilter) ProtoReflect ¶
func (x *RatingFilter) ProtoReflect() protoreflect.Message
func (*RatingFilter) Reset ¶
func (x *RatingFilter) Reset()
func (*RatingFilter) String ¶
func (x *RatingFilter) String() string
type TypeFilter ¶
type TypeFilter struct {
// Optional. Included Place types.
IncludedTypes []string `protobuf:"bytes,1,rep,name=included_types,json=includedTypes,proto3" json:"included_types,omitempty"`
// Optional. Excluded Place types.
ExcludedTypes []string `protobuf:"bytes,2,rep,name=excluded_types,json=excludedTypes,proto3" json:"excluded_types,omitempty"`
// Optional. Included primary Place types.
IncludedPrimaryTypes []string `protobuf:"bytes,3,rep,name=included_primary_types,json=includedPrimaryTypes,proto3" json:"included_primary_types,omitempty"`
// Optional. Excluded primary Place types.
ExcludedPrimaryTypes []string `protobuf:"bytes,4,rep,name=excluded_primary_types,json=excludedPrimaryTypes,proto3" json:"excluded_primary_types,omitempty"`
// contains filtered or unexported fields
}
Place type filters.
Only Place types from [Table a](https://developers.google.com/maps/documentation/places/web-service/place-types#table-a) are supported.
A place can only have a single primary type associated with it. For example, the primary type might be "mexican_restaurant" or "steak_house". Use included_primary_types and excluded_primary_types to filter the results on a place's primary type.
A place can also have multiple type values associated with it. For example a restaurant might have the following types: "seafood_restaurant", "restaurant", "food", "point_of_interest", "establishment". Use included_types and excluded_types to filter the results on the list of types associated with a place.
If a search is specified with multiple type restrictions, only places that satisfy all of the restrictions are returned. For example, if you specify {"included_types": ["restaurant"], "excluded_primary_types": ["steak_house"]}, the returned places provide "restaurant" related services but do not operate primarily as a "steak_house".
If there are any conflicting types, i.e. a type appears in both included_types and excluded_types types or included_primary_types and excluded_primary_types, an INVALID_ARGUMENT error is returned.
One of included_types or included_primary_types must be set.
func (*TypeFilter) Descriptor
deprecated
func (*TypeFilter) Descriptor() ([]byte, []int)
Deprecated: Use TypeFilter.ProtoReflect.Descriptor instead.
func (*TypeFilter) GetExcludedPrimaryTypes ¶
func (x *TypeFilter) GetExcludedPrimaryTypes() []string
func (*TypeFilter) GetExcludedTypes ¶
func (x *TypeFilter) GetExcludedTypes() []string
func (*TypeFilter) GetIncludedPrimaryTypes ¶
func (x *TypeFilter) GetIncludedPrimaryTypes() []string
func (*TypeFilter) GetIncludedTypes ¶
func (x *TypeFilter) GetIncludedTypes() []string
func (*TypeFilter) ProtoMessage ¶
func (*TypeFilter) ProtoMessage()
func (*TypeFilter) ProtoReflect ¶
func (x *TypeFilter) ProtoReflect() protoreflect.Message
func (*TypeFilter) Reset ¶
func (x *TypeFilter) Reset()
func (*TypeFilter) String ¶
func (x *TypeFilter) String() string
type UnimplementedAreaInsightsServer ¶
type UnimplementedAreaInsightsServer struct {
}
UnimplementedAreaInsightsServer should be embedded to have forward compatible implementations.
func (UnimplementedAreaInsightsServer) ComputeInsights ¶
func (UnimplementedAreaInsightsServer) ComputeInsights(context.Context, *ComputeInsightsRequest) (*ComputeInsightsResponse, error)
type UnsafeAreaInsightsServer ¶ added in v1.24.0
type UnsafeAreaInsightsServer interface {
// contains filtered or unexported methods
}
UnsafeAreaInsightsServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to AreaInsightsServer will result in compilation errors.